<?php
/**
 * @package     Joomla.Site
 * @subpackage  com_joomla_lms
 *
 */

namespace LMS\Tools\Conference\Controllers;

defined('_JEXEC') or die;

require __DIR__ .'/conference.php';

/**
 * @package     Joomla.Site
 * @subpackage  com_joomla_lms
 * @since       3.1
 */
class User extends Conference
{

	public function __construct($config=array())
	{
		parent::__construct($config);
		$this->input->set('view', 'user');
	}


	/**
	 * Method to display a view.
	 *
	 * @param   boolean			If true, the view output will be cached
	 * @param   array  An array of safe url parameters and their variable types, for valid values see {@link JFilterInput::clean()}.
	 *
	 * @return  \JController		This object to support chaining.
	 * @since   1.5
	 */
	public function display($cachable = false, $urlparams = false)
	{

		$results = $this->dispatcher->trigger( 'onConferenceUserAccess', array($this->container));
		$result = $this->responseHandler->handle($results);

		$this->_render(array('content' => $result));

	}

	/**
	 * Method to show form for save new attendee of conference
	 */
	public function save()
	{
		if(!$this->acl->CheckPermissions('conference', 'manage')){
			throw new \LMS\Libraries\Exception\Access\Forbidden(_JLMS_ERROR_ACCESS_FORBIDDEN);
		}

		$params = $this->container['registry']->get('params');

		$results = $this->dispatcher->trigger( 'onConferenceSaveUserAccess', array($this->container));
		$this->responseHandler->handle($results);
		$this->setRedirect(html_entity_decode(sefRelToAbs('index.php?option=com_joomla_lms&Itemdid='.$params['Itemid'].'&task=conference.user&id='.$params['courseID'].'&bookedConferenceID='.$params['bookedConferenceID'])));
	}


	/**
	 * Method to delete existing attendee
	 */
	public function delete()
	{
		if(!$this->acl->CheckPermissions('conference', 'manage')){
			throw new \LMS\Libraries\Exception\Access\Forbidden(_JLMS_ERROR_ACCESS_FORBIDDEN);
		}

		$params = $this->container['registry']->get('params');
		$results = $this->dispatcher->trigger( 'onConferenceDeleteUser', array($this->container));
		$this->responseHandler->handle($results);
		$this->setRedirect(html_entity_decode(sefRelToAbs('index.php?option=com_joomla_lms&Itemdid='.$params['Itemid'].'&task=conference.user&id='.$params['courseID'].'&bookedConferenceID='.$params['bookedConferenceID'])));
	}

}